sequencetools
=============

.. automodule:: abjad.tools.sequencetools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.sequencetools.all_are_assignable_integers.all_are_assignable_integers
      ~abjad.tools.sequencetools.all_are_equal.all_are_equal
      ~abjad.tools.sequencetools.all_are_integer_equivalent_exprs.all_are_integer_equivalent_exprs
      ~abjad.tools.sequencetools.all_are_integer_equivalent_numbers.all_are_integer_equivalent_numbers
      ~abjad.tools.sequencetools.all_are_nonnegative_integer_equivalent_numbers.all_are_nonnegative_integer_equivalent_numbers
      ~abjad.tools.sequencetools.all_are_nonnegative_integer_powers_of_two.all_are_nonnegative_integer_powers_of_two
      ~abjad.tools.sequencetools.all_are_nonnegative_integers.all_are_nonnegative_integers
      ~abjad.tools.sequencetools.all_are_numbers.all_are_numbers
      ~abjad.tools.sequencetools.all_are_pairs.all_are_pairs
      ~abjad.tools.sequencetools.all_are_pairs_of_types.all_are_pairs_of_types
      ~abjad.tools.sequencetools.all_are_positive_integer_equivalent_numbers.all_are_positive_integer_equivalent_numbers
      ~abjad.tools.sequencetools.all_are_positive_integers.all_are_positive_integers
      ~abjad.tools.sequencetools.all_are_unequal.all_are_unequal
      ~abjad.tools.sequencetools.count_length_two_runs_in_sequence.count_length_two_runs_in_sequence
      ~abjad.tools.sequencetools.divide_sequence_elements_by_greatest_common_divisor.divide_sequence_elements_by_greatest_common_divisor
      ~abjad.tools.sequencetools.flatten_sequence.flatten_sequence
      ~abjad.tools.sequencetools.flatten_sequence_at_indices.flatten_sequence_at_indices
      ~abjad.tools.sequencetools.get_indices_of_sequence_elements_equal_to_true.get_indices_of_sequence_elements_equal_to_true
      ~abjad.tools.sequencetools.get_sequence_degree_of_rotational_symmetry.get_sequence_degree_of_rotational_symmetry
      ~abjad.tools.sequencetools.get_sequence_element_at_cyclic_index.get_sequence_element_at_cyclic_index
      ~abjad.tools.sequencetools.get_sequence_elements_at_indices.get_sequence_elements_at_indices
      ~abjad.tools.sequencetools.get_sequence_elements_frequency_distribution.get_sequence_elements_frequency_distribution
      ~abjad.tools.sequencetools.get_sequence_period_of_rotation.get_sequence_period_of_rotation
      ~abjad.tools.sequencetools.increase_sequence_elements_at_indices_by_addenda.increase_sequence_elements_at_indices_by_addenda
      ~abjad.tools.sequencetools.increase_sequence_elements_cyclically_by_addenda.increase_sequence_elements_cyclically_by_addenda
      ~abjad.tools.sequencetools.interlace_sequences.interlace_sequences
      ~abjad.tools.sequencetools.is_fraction_equivalent_pair.is_fraction_equivalent_pair
      ~abjad.tools.sequencetools.is_integer_equivalent_n_tuple.is_integer_equivalent_n_tuple
      ~abjad.tools.sequencetools.is_integer_equivalent_pair.is_integer_equivalent_pair
      ~abjad.tools.sequencetools.is_integer_equivalent_singleton.is_integer_equivalent_singleton
      ~abjad.tools.sequencetools.is_integer_n_tuple.is_integer_n_tuple
      ~abjad.tools.sequencetools.is_integer_pair.is_integer_pair
      ~abjad.tools.sequencetools.is_integer_singleton.is_integer_singleton
      ~abjad.tools.sequencetools.is_monotonically_decreasing_sequence.is_monotonically_decreasing_sequence
      ~abjad.tools.sequencetools.is_monotonically_increasing_sequence.is_monotonically_increasing_sequence
      ~abjad.tools.sequencetools.is_n_tuple.is_n_tuple
      ~abjad.tools.sequencetools.is_null_tuple.is_null_tuple
      ~abjad.tools.sequencetools.is_pair.is_pair
      ~abjad.tools.sequencetools.is_permutation.is_permutation
      ~abjad.tools.sequencetools.is_repetition_free_sequence.is_repetition_free_sequence
      ~abjad.tools.sequencetools.is_restricted_growth_function.is_restricted_growth_function
      ~abjad.tools.sequencetools.is_singleton.is_singleton
      ~abjad.tools.sequencetools.is_strictly_decreasing_sequence.is_strictly_decreasing_sequence
      ~abjad.tools.sequencetools.is_strictly_increasing_sequence.is_strictly_increasing_sequence
      ~abjad.tools.sequencetools.iterate_sequence_cyclically.iterate_sequence_cyclically
      ~abjad.tools.sequencetools.iterate_sequence_cyclically_from_start_to_stop.iterate_sequence_cyclically_from_start_to_stop
      ~abjad.tools.sequencetools.iterate_sequence_forward_and_backward_nonoverlapping.iterate_sequence_forward_and_backward_nonoverlapping
      ~abjad.tools.sequencetools.iterate_sequence_forward_and_backward_overlapping.iterate_sequence_forward_and_backward_overlapping
      ~abjad.tools.sequencetools.iterate_sequence_nwise_cyclic.iterate_sequence_nwise_cyclic
      ~abjad.tools.sequencetools.iterate_sequence_nwise_strict.iterate_sequence_nwise_strict
      ~abjad.tools.sequencetools.iterate_sequence_nwise_wrapped.iterate_sequence_nwise_wrapped
      ~abjad.tools.sequencetools.iterate_sequence_pairwise_cyclic.iterate_sequence_pairwise_cyclic
      ~abjad.tools.sequencetools.iterate_sequence_pairwise_strict.iterate_sequence_pairwise_strict
      ~abjad.tools.sequencetools.iterate_sequence_pairwise_wrapped.iterate_sequence_pairwise_wrapped
      ~abjad.tools.sequencetools.join_subsequences.join_subsequences
      ~abjad.tools.sequencetools.join_subsequences_by_sign_of_subsequence_elements.join_subsequences_by_sign_of_subsequence_elements
      ~abjad.tools.sequencetools.map_sequence_elements_to_canonic_tuples.map_sequence_elements_to_canonic_tuples
      ~abjad.tools.sequencetools.map_sequence_elements_to_numbered_sublists.map_sequence_elements_to_numbered_sublists
      ~abjad.tools.sequencetools.merge_duration_sequences.merge_duration_sequences
      ~abjad.tools.sequencetools.negate_absolute_value_of_sequence_elements_at_indices.negate_absolute_value_of_sequence_elements_at_indices
      ~abjad.tools.sequencetools.negate_absolute_value_of_sequence_elements_cyclically.negate_absolute_value_of_sequence_elements_cyclically
      ~abjad.tools.sequencetools.negate_sequence_elements_at_indices.negate_sequence_elements_at_indices
      ~abjad.tools.sequencetools.negate_sequence_elements_cyclically.negate_sequence_elements_cyclically
      ~abjad.tools.sequencetools.overwrite_sequence_elements_at_indices.overwrite_sequence_elements_at_indices
      ~abjad.tools.sequencetools.pair_duration_sequence_elements_with_input_pair_values.pair_duration_sequence_elements_with_input_pair_values
      ~abjad.tools.sequencetools.partition_sequence_by_backgrounded_weights.partition_sequence_by_backgrounded_weights
      ~abjad.tools.sequencetools.partition_sequence_by_counts.partition_sequence_by_counts
      ~abjad.tools.sequencetools.partition_sequence_by_ratio_of_lengths.partition_sequence_by_ratio_of_lengths
      ~abjad.tools.sequencetools.partition_sequence_by_ratio_of_weights.partition_sequence_by_ratio_of_weights
      ~abjad.tools.sequencetools.partition_sequence_by_restricted_growth_function.partition_sequence_by_restricted_growth_function
      ~abjad.tools.sequencetools.partition_sequence_by_sign_of_elements.partition_sequence_by_sign_of_elements
      ~abjad.tools.sequencetools.partition_sequence_by_value_of_elements.partition_sequence_by_value_of_elements
      ~abjad.tools.sequencetools.partition_sequence_by_weights_at_least.partition_sequence_by_weights_at_least
      ~abjad.tools.sequencetools.partition_sequence_by_weights_at_most.partition_sequence_by_weights_at_most
      ~abjad.tools.sequencetools.partition_sequence_by_weights_exactly.partition_sequence_by_weights_exactly
      ~abjad.tools.sequencetools.partition_sequence_extended_to_counts.partition_sequence_extended_to_counts
      ~abjad.tools.sequencetools.permute_sequence.permute_sequence
      ~abjad.tools.sequencetools.remap_sequence_by_range_pairs.remap_sequence_by_range_pairs
      ~abjad.tools.sequencetools.remove_sequence_elements_at_indices.remove_sequence_elements_at_indices
      ~abjad.tools.sequencetools.remove_sequence_elements_at_indices_cyclically.remove_sequence_elements_at_indices_cyclically
      ~abjad.tools.sequencetools.remove_subsequence_of_weight_at_index.remove_subsequence_of_weight_at_index
      ~abjad.tools.sequencetools.repeat_runs_in_sequence_to_count.repeat_runs_in_sequence_to_count
      ~abjad.tools.sequencetools.repeat_sequence_elements_at_indices.repeat_sequence_elements_at_indices
      ~abjad.tools.sequencetools.repeat_sequence_elements_at_indices_cyclically.repeat_sequence_elements_at_indices_cyclically
      ~abjad.tools.sequencetools.repeat_sequence_elements_n_times_each.repeat_sequence_elements_n_times_each
      ~abjad.tools.sequencetools.repeat_sequence_n_times.repeat_sequence_n_times
      ~abjad.tools.sequencetools.repeat_sequence_to_length.repeat_sequence_to_length
      ~abjad.tools.sequencetools.repeat_sequence_to_weight_at_least.repeat_sequence_to_weight_at_least
      ~abjad.tools.sequencetools.repeat_sequence_to_weight_at_most.repeat_sequence_to_weight_at_most
      ~abjad.tools.sequencetools.repeat_sequence_to_weight_exactly.repeat_sequence_to_weight_exactly
      ~abjad.tools.sequencetools.replace_sequence_elements_cyclically_with_new_material.replace_sequence_elements_cyclically_with_new_material
      ~abjad.tools.sequencetools.retain_sequence_elements_at_indices.retain_sequence_elements_at_indices
      ~abjad.tools.sequencetools.retain_sequence_elements_at_indices_cyclically.retain_sequence_elements_at_indices_cyclically
      ~abjad.tools.sequencetools.reverse_sequence.reverse_sequence
      ~abjad.tools.sequencetools.reverse_sequence_elements.reverse_sequence_elements
      ~abjad.tools.sequencetools.rotate_sequence.rotate_sequence
      ~abjad.tools.sequencetools.splice_new_elements_between_sequence_elements.splice_new_elements_between_sequence_elements
      ~abjad.tools.sequencetools.split_sequence_by_weights.split_sequence_by_weights
      ~abjad.tools.sequencetools.split_sequence_extended_to_weights.split_sequence_extended_to_weights
      ~abjad.tools.sequencetools.sum_consecutive_sequence_elements_by_sign.sum_consecutive_sequence_elements_by_sign
      ~abjad.tools.sequencetools.sum_sequence_elements_at_indices.sum_sequence_elements_at_indices
      ~abjad.tools.sequencetools.truncate_runs_in_sequence.truncate_runs_in_sequence
      ~abjad.tools.sequencetools.truncate_sequence_to_sum.truncate_sequence_to_sum
      ~abjad.tools.sequencetools.truncate_sequence_to_weight.truncate_sequence_to_weight
      ~abjad.tools.sequencetools.yield_all_combinations_of_sequence_elements.yield_all_combinations_of_sequence_elements
      ~abjad.tools.sequencetools.yield_all_k_ary_sequences_of_length.yield_all_k_ary_sequences_of_length
      ~abjad.tools.sequencetools.yield_all_pairs_between_sequences.yield_all_pairs_between_sequences
      ~abjad.tools.sequencetools.yield_all_partitions_of_sequence.yield_all_partitions_of_sequence
      ~abjad.tools.sequencetools.yield_all_permutations_of_sequence.yield_all_permutations_of_sequence
      ~abjad.tools.sequencetools.yield_all_permutations_of_sequence_in_orbit.yield_all_permutations_of_sequence_in_orbit
      ~abjad.tools.sequencetools.yield_all_restricted_growth_functions_of_length.yield_all_restricted_growth_functions_of_length
      ~abjad.tools.sequencetools.yield_all_rotations_of_sequence.yield_all_rotations_of_sequence
      ~abjad.tools.sequencetools.yield_all_set_partitions_of_sequence.yield_all_set_partitions_of_sequence
      ~abjad.tools.sequencetools.yield_all_subsequences_of_sequence.yield_all_subsequences_of_sequence
      ~abjad.tools.sequencetools.yield_all_unordered_pairs_of_sequence.yield_all_unordered_pairs_of_sequence
      ~abjad.tools.sequencetools.yield_outer_product_of_sequences.yield_outer_product_of_sequences
      ~abjad.tools.sequencetools.zip_sequences_cyclically.zip_sequences_cyclically
      ~abjad.tools.sequencetools.zip_sequences_without_truncation.zip_sequences_without_truncation
